@@ -1,5 +1,5 @@
 /* EasyTAG - tag editor for audio files
- * Copyright (C) 2014  David King <amigadave@amigadave.com>
+ * Copyright (C) 2014-2015  David King <amigadave@amigadave.com>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -33,7 +33,7 @@
 typedef struct
 {
     guint idle_handler;
-    gchar *init_directory;
+    GFile *init_directory;
 } EtApplicationPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (EtApplication, et_application, GTK_TYPE_APPLICATION)
@@ -50,19 +50,23 @@ on_help (GSimpleAction *action,
          GVariant *parameter,
          gpointer user_data)
 {
-/* TODO: Link to help.gnome.org, or locally-installed help, on Windows. */
-#ifndef G_OS_WIN32
     GError *error = NULL;
 
+#ifndef G_OS_WIN32
     gtk_show_uri (gtk_window_get_screen (GTK_WINDOW (MainWindow)),
                   "help:easytag", GDK_CURRENT_TIME, &error);
+#else /* G_OS_WIN32 */
+    /* TODO: Link to locally-installed help on Windows. */
+    gtk_show_uri (gtk_window_get_screen (GTK_WINDOW (MainWindow)),
+                  "https://help.gnome.org/users/easytag/stable/",
+                  GDK_CURRENT_TIME, &error);
+#endif
 
     if (error)
     {
         g_debug ("Error while opening help: %s", error->message);
         g_error_free (error);
     }
-#endif
 }
 
 static void
@@ -165,13 +169,7 @@ common_init (EtApplication *self)
     /* Starting messages */
     Log_Print (LOG_OK, _("Starting EasyTAG version %s…"), PACKAGE_VERSION);
 #ifdef G_OS_WIN32
-    if (g_getenv("EASYTAGLANG"))
-    {
-        Log_Print (LOG_OK,
-                   _("Variable EASYTAGLANG defined, setting locale ‘%s’"),
-                   g_getenv ("EASYTAGLANG"));
-    }
-    else
+    if (g_getenv ("LANG"))
     {
         Log_Print (LOG_OK, _("Setting locale: ‘%s’"), g_getenv ("LANG"));
     }
@@ -397,7 +395,7 @@ et_application_open (GApplication *self,
     GError *err = NULL;
     GFileType type;
     gchar *path;
-    gchar *path_utf8;
+    gchar *display_path;
 
     priv = et_application_get_instance_private (ET_APPLICATION (self));
 
@@ -410,47 +408,45 @@ et_application_open (GApplication *self,
     check_for_hidden_path_in_tree (arg);
 
     path = g_file_get_path (arg);
-    path_utf8 = filename_to_display (path);
+    display_path = g_filename_display_name (path);
     info = g_file_query_info (arg, G_FILE_ATTRIBUTE_STANDARD_TYPE,
                               G_FILE_QUERY_INFO_NONE, NULL, &err);
 
+    g_free (path);
+
     if (info == NULL)
     {
         if (activated)
         {
             Log_Print (LOG_ERROR, _("Error while querying information for file ‘%s’: %s"),
-                       path_utf8, err->message);
+                       display_path, err->message);
 
         }
         else
         {
             g_warning ("Error while querying information for file: '%s' (%s)",
-                       path_utf8, err->message);
+                       display_path, err->message);
         }
 
-        g_free (path);
-        g_free (path_utf8);
+        g_free (display_path);
         g_error_free (err);
         return;
     }
 
     type = g_file_info_get_file_type (info);
+    g_object_unref (info);
 
     if (type == G_FILE_TYPE_DIRECTORY)
     {
         if (activated)
         {
             et_application_window_select_dir (ET_APPLICATION_WINDOW (window),
-                                              path);
-            g_free (path);
+                                              arg);
         }
         else
         {
-            priv->init_directory = path;
+            priv->init_directory = g_object_ref (arg);
         }
-
-        g_free (path_utf8);
-        g_object_unref (info);
     }
     else if (type == G_FILE_TYPE_REGULAR)
     {
@@ -459,43 +455,32 @@ et_application_open (GApplication *self,
 
         if (parent)
         {
-            g_free (path_utf8);
-            g_free (path);
-
             if (activated)
             {
-                gchar *parent_path;
-
-                parent_path = g_file_get_path (arg);
                 et_application_window_select_dir (ET_APPLICATION_WINDOW (window),
-                                                  parent_path);
-
-                g_free (parent_path);
+                                                  parent);
             }
             else
             {
-                priv->init_directory = g_file_get_path (parent);
+                priv->init_directory = parent;
             }
-
-            g_object_unref (parent);
-            g_object_unref (info);
         }
         else
         {
-            Log_Print (LOG_WARNING, _("Cannot open path ‘%s’"), path_utf8);
-            g_free (path);
-            g_free (path_utf8);
+            Log_Print (LOG_WARNING, _("Cannot open path ‘%s’"), display_path);
+            g_free (display_path);
             return;
         }
     }
     else
     {
-        Log_Print (LOG_WARNING, _("Cannot open path ‘%s’"), path_utf8);
-        g_free (path);
-        g_free (path_utf8);
+        Log_Print (LOG_WARNING, _("Cannot open path ‘%s’"), display_path);
+        g_free (display_path);
         return;
     }
 
+    g_free (display_path);
+
     if (!activated)
     {
         common_init (ET_APPLICATION (self));
@@ -570,7 +555,11 @@ et_application_finalize (GObject *object)
     self = ET_APPLICATION (object);
     priv = et_application_get_instance_private (self);
 
-    g_free (priv->init_directory);
+    if (priv->init_directory)
+    {
+        g_object_unref (priv->init_directory);
+        priv->init_directory = NULL;
+    }
 
     G_OBJECT_CLASS (et_application_parent_class)->finalize (object);
 }
