@@ -21,9 +21,9 @@
 #include "file.h"
 
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 #include <string.h>
 #include <stdlib.h>
-#include <sys/stat.h>
 #include <unistd.h>
 #include <utime.h>
 
@@ -1352,6 +1352,24 @@ ET_Save_File_Tag_To_HD (ET_File *ETFile, GError **error)
         case OPUS_TAG:
             state = ogg_tag_write_file_tag (ETFile, error);
             break;
+#endif
+#ifndef ENABLE_MP3
+        case ID3_TAG:
+#endif
+#ifndef ENABLE_OGG
+        case OGG_TAG:
+#endif
+#ifndef ENABLE_FLAC
+        case FLAC_TAG:
+#endif
+#ifndef ENABLE_MP4
+        case MP4_TAG:
+#endif
+#ifndef ENABLE_WAVPACK
+        case WAVPACK_TAG:
+#endif
+#ifndef ENABLE_OPUS
+        case OPUS_TAG:
 #endif
         case UNKNOWN_TAG:
         default:
@@ -1403,7 +1421,7 @@ ET_Save_File_Tag_To_HD (ET_File *ETFile, GError **error)
                                     "file-update-parent-modification-time"))
         {
             gchar *path = g_path_get_dirname (cur_filename);
-            utime (path, NULL);
+            g_utime (path, NULL);
             g_free (path);
         }
 
@@ -1838,11 +1856,10 @@ ET_File_Format_File_Extension (const ET_File *ETFile)
 
     switch (mode)
     {
-        /* FIXME: Should use filename encoding, not UTF-8! */
         case ET_FILENAME_EXTENSION_LOWER_CASE:
-            return g_utf8_strdown (ETFile->ETFileDescription->Extension, -1);
+            return g_ascii_strdown (ETFile->ETFileDescription->Extension, -1);
         case ET_FILENAME_EXTENSION_UPPER_CASE:
-            return g_utf8_strup (ETFile->ETFileDescription->Extension, -1);
+            return g_ascii_strup (ETFile->ETFileDescription->Extension, -1);
         case ET_FILENAME_EXTENSION_NO_CHANGE:
         default:
             return g_strdup (ETFile->ETFileExtension);
