@@ -27,7 +27,6 @@
 #include <stdlib.h>
 #include <sys/stat.h>
 #include <unistd.h>
-#include <utime.h>
 
 #include "application_window.h"
 #include "charset.h"
@@ -210,7 +209,7 @@ et_file_list_add (GList *file_list,
     guint         undo_key;
     GFileInfo *fileinfo;
     gchar *filename;
-    gchar *filename_utf8;
+    gchar *display_path;
     const gchar  *locale_lc_ctype = getenv("LC_CTYPE");
     GError *error = NULL;
     gboolean success;
@@ -222,7 +221,7 @@ et_file_list_add (GList *file_list,
 
     /* Get description of the file */
     filename = g_file_get_path (file);
-    filename_utf8 = filename_to_display (filename);
+    display_path = g_filename_display_name (filename);
     description = ET_Get_File_Description (filename);
 
     /* Get real extension of the file (keeping the case) */
@@ -231,7 +230,7 @@ et_file_list_add (GList *file_list,
     /* Fill the File_Name structure for FileNameList */
     FileName = et_file_name_new ();
     FileName->saved      = TRUE;    /* The file hasn't been changed, so it's saved */
-    ET_Set_Filename_File_Name_Item (FileName, filename_utf8, filename);
+    ET_Set_Filename_File_Name_Item (FileName, display_path, filename);
 
     /* Fill the File_Tag structure for FileTagList */
     FileTag = et_file_tag_new ();
@@ -251,7 +250,7 @@ et_file_list_add (GList *file_list,
             {
                 Log_Print (LOG_ERROR,
                            _("Error reading ID3 tag from file ‘%s’: %s"),
-                           filename_utf8, error->message);
+                           display_path, error->message);
                 g_clear_error (&error);
             }
             break;
@@ -262,7 +261,7 @@ et_file_list_add (GList *file_list,
             {
                 Log_Print (LOG_ERROR,
                            _("Error reading tag from Ogg file ‘%s’: %s"),
-                           filename_utf8, error->message);
+                           display_path, error->message);
                 g_clear_error (&error);
             }
             break;
@@ -273,7 +272,7 @@ et_file_list_add (GList *file_list,
             {
                 Log_Print (LOG_ERROR,
                            _("Error reading tag from FLAC file ‘%s’: %s"),
-                           filename_utf8, error->message);
+                           display_path, error->message);
                 g_clear_error (&error);
             }
             break;
@@ -283,7 +282,7 @@ et_file_list_add (GList *file_list,
             {
                 Log_Print (LOG_ERROR,
                            _("Error reading APE tag from file ‘%s’: %s"),
-                           filename_utf8, error->message);
+                           display_path, error->message);
                 g_clear_error (&error);
             }
             break;
@@ -293,7 +292,7 @@ et_file_list_add (GList *file_list,
             {
                 Log_Print (LOG_ERROR,
                            _("Error reading tag from MP4 file ‘%s’: %s"),
-                           filename_utf8, error->message);
+                           display_path, error->message);
                 g_clear_error (&error);
             }
             break;
@@ -304,7 +303,7 @@ et_file_list_add (GList *file_list,
             {
                 Log_Print (LOG_ERROR,
                            _("Error reading tag from WavPack file ‘%s’: %s"),
-                           filename_utf8, error->message);
+                           display_path, error->message);
                 g_clear_error (&error);
             }
         break;
@@ -315,7 +314,7 @@ et_file_list_add (GList *file_list,
             {
                 Log_Print (LOG_ERROR,
                            _("Error reading tag from Opus file ‘%s’: %s"),
-                           filename_utf8, error->message);
+                           display_path, error->message);
                 g_clear_error (&error);
             }
             break;
@@ -343,7 +342,7 @@ et_file_list_add (GList *file_list,
             /* FIXME: Translatable string. */
             Log_Print (LOG_ERROR,
                        "FileTag: Undefined tag type (%d) for file %s",
-                       (gint)description->TagType, filename_utf8);
+                       (gint)description->TagType, display_path);
             break;
     }
 
@@ -351,7 +350,7 @@ et_file_list_add (GList *file_list,
     {
         Log_Print (LOG_WARNING,
                    _("The year value ‘%s’ seems to be invalid in file ‘%s’. The information will be lost when saving"),
-                   FileTag->year, filename_utf8);
+                   FileTag->year, display_path);
     }
 
     /* Fill the ET_File_Info structure */
@@ -431,7 +430,7 @@ et_file_list_add (GList *file_list,
             /* FIXME: Translatable string. */
             Log_Print (LOG_ERROR,
                        "ETFileInfo: Undefined file type (%d) for file %s",
-                       (gint)description->FileType, filename_utf8);
+                       (gint)description->FileType, display_path);
             /* To get at least the file size. */
             success = et_core_read_file_info (file, ETFileInfo, &error);
             break;
@@ -441,7 +440,7 @@ et_file_list_add (GList *file_list,
     {
         Log_Print (LOG_ERROR,
                    _("Error while querying information for file ‘%s’: %s"),
-                   filename_utf8, error->message);
+                   display_path, error->message);
         g_error_free (error);
     }
 
@@ -510,7 +509,7 @@ et_file_list_add (GList *file_list,
     if ( (FileName && FileName->saved==FALSE) || (FileTag && FileTag->saved==FALSE) )
     {
         Log_Print (LOG_INFO, _("Automatic corrections applied for file ‘%s’"),
-                   filename_utf8);
+                   display_path);
     }
 
     /* Add the item to the ArtistAlbum list (placed here to take advantage of previous changes) */
@@ -519,7 +518,7 @@ et_file_list_add (GList *file_list,
     //ET_Debug_Print_File_List(ETCore->ETFileList,__FILE__,__LINE__,__FUNCTION__);
 
     g_free (filename);
-    g_free (filename_utf8);
+    g_free (display_path);
 
     return result;
 }
@@ -617,7 +616,6 @@ et_artist_album_list_add_file (GList *file_list,
     GList *ArtistList;
     GList *AlbumList = NULL;
     GList *etfilelist = NULL;
-    GList *result;
     ET_File *etfile = NULL;
 
     g_return_val_if_fail (ETFile != NULL, NULL);
@@ -668,10 +666,9 @@ et_artist_album_list_add_file (GList *file_list,
                 {
                     /* The "AlbumList" item was found!
                      * Add the ETFile to this AlbumList item */
-                    AlbumList->data = g_list_append ((GList *)AlbumList->data,
-                                                     ETFile);
-                    AlbumList->data = g_list_sort ((GList *)AlbumList->data,
-                                                   (GCompareFunc)ET_Comp_Func_Sort_Etfile_Item_By_Ascending_Filename);
+                    AlbumList->data = g_list_insert_sorted ((GList *)AlbumList->data,
+                                                            ETFile,
+                                                            (GCompareFunc)ET_Comp_Func_Sort_Etfile_Item_By_Ascending_Filename);
                     return file_list;
                 }
 
@@ -681,10 +678,9 @@ et_artist_album_list_add_file (GList *file_list,
             /* The "AlbumList" item was NOT found! => Add a new "AlbumList"
              * item (+...) item to the "ArtistList" list. */
             etfilelist = g_list_append (NULL, ETFile);
-            ArtistList->data = g_list_append ((GList *)ArtistList->data,
-                                              etfilelist);
-            ArtistList->data = g_list_sort ((GList *)ArtistList->data,
-                                            (GCompareFunc)ET_Comp_Func_Sort_Album_Item_By_Ascending_Album);
+            ArtistList->data = g_list_insert_sorted ((GList *)ArtistList->data,
+                                                     etfilelist,
+                                                     (GCompareFunc)ET_Comp_Func_Sort_Album_Item_By_Ascending_Album);
             return file_list;
         }
     }
@@ -693,14 +689,10 @@ et_artist_album_list_add_file (GList *file_list,
      * main list (=ETArtistAlbumFileList). */
     etfilelist = g_list_append (NULL, ETFile);
     AlbumList  = g_list_append (NULL, etfilelist);
-    file_list = g_list_append (file_list, AlbumList);
 
     /* Sort the list by ascending Artist. */
-    /* TODO: Use g_list_insert_sorted() instead. */
-    result = g_list_sort (file_list,
-                          (GCompareFunc)ET_Comp_Func_Sort_Artist_Item_By_Ascending_Artist);
-
-    return result;
+    return g_list_insert_sorted (file_list, AlbumList,
+                                 (GCompareFunc)ET_Comp_Func_Sort_Artist_Item_By_Ascending_Artist);
 }
 
 GList *
@@ -787,7 +779,7 @@ et_displayed_file_list_length (GList *displayed_list)
     GList *list;
 
     list = g_list_first (displayed_list);
-    return g_list_length (list);;
+    return g_list_length (list);
 }
 
 /*
@@ -842,21 +834,17 @@ ET_Remove_File_From_File_List (ET_File *ETFile)
     }
 
     /* Remove the file from the ETFileList list. */
-    ETCore->ETFileList = g_list_remove (ETCore->ETFileList, ETFileList);
+    ETCore->ETFileList = g_list_remove (ETCore->ETFileList, ETFile);
 
     // Remove the file from the ETArtistAlbumList list
     ET_Remove_File_From_Artist_Album_List(ETFile);
 
     /* Remove the file from the ETFileDisplayedList list (if not already). */
     ETCore->ETFileDisplayedList = g_list_remove (g_list_first (ETCore->ETFileDisplayedList),
-                                                 ETFileDisplayedList);
+                                                 ETFile);
 
     // Free data of the file
     ET_Free_File_List_Item(ETFile);
-    if (ETFileList)
-        g_list_free(ETFileList);
-    if (ETFileDisplayedList)
-        g_list_free(ETFileDisplayedList);
 
     /* Recalculate length of ETFileDisplayedList list. */
     ETCore->ETFileDisplayedList_Length = et_displayed_file_list_length (ETCore->ETFileDisplayedList);
@@ -956,7 +944,6 @@ ET_Sort_File_List (GList *ETFileList,
     /* Important to rewind before. */
     etfilelist = g_list_first (ETFileList);
 
-    /* FIXME: Port to sort-mode? */
     set_sort_order_for_column_id (column_id, column, Sorting_Type);
 
     /* Sort... */
@@ -1158,12 +1145,8 @@ ET_Displayed_File_List_By_Etfile (const ET_File *ETFile)
 {
     GList *etfilelist;
 
-    for (etfilelist = ET_Displayed_File_List_First (); etfilelist != NULL;
-         etfilelist = ET_Displayed_File_List_Next ())
-    {
-        if (ETFile == (ET_File *)etfilelist->data)
-            break;
-    }
+    etfilelist = g_list_find (g_list_first (ETCore->ETFileDisplayedList),
+                              ETFile);
 
     if (etfilelist)
     {
@@ -1171,6 +1154,7 @@ ET_Displayed_File_List_By_Etfile (const ET_File *ETFile)
          * FIXME) */
         ETCore->ETFileDisplayedList = etfilelist;
     }
+
     return etfilelist;
 }
 
@@ -1201,6 +1185,10 @@ et_displayed_file_list_set (GList *ETFileList)
                        g_settings_get_enum (MainSettings,
                                             "sort-mode"));
 
+    /* Synchronize, so that the core file list pointer always points to the
+     * head of the list. */
+    ETCore->ETFileList = g_list_first (ETCore->ETFileList);
+
     /* Should renums ETCore->ETFileDisplayedList only! */
     et_displayed_file_list_renumber (ETCore->ETFileDisplayedList);
 }
@@ -1221,8 +1209,8 @@ et_file_list_update_directory_name (GList *file_list,
     gchar *old_path_tmp;
 
     g_return_if_fail (file_list != NULL);
-    g_return_if_fail (old_path != NULL && *old_path != '\0');
-    g_return_if_fail (new_path != NULL && *new_path != '\0');
+    g_return_if_fail (!et_str_empty (old_path));
+    g_return_if_fail (!et_str_empty (new_path));
 
     /* Add '/' to end of path to avoid ambiguity between a directory and a
      * filename... */
