@@ -22,6 +22,7 @@
 #include "misc.h"
 
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 #include <stdlib.h>
 #include <sys/stat.h>
 
@@ -430,12 +431,13 @@ et_rename_file (const char *old_filepath,
             tmp_filename = g_strconcat (old_filepath, ".XXXXXX", NULL);
 
             old_mode = umask (077);
-            fd = mkstemp (tmp_filename);
+            fd = g_mkstemp (tmp_filename);
             umask (old_mode);
 
             if (fd >= 0)
             {
-                close (fd);
+                /* TODO: Handle error. */
+                g_close (fd, NULL);
             }
 
             tmp_file = g_file_new_for_path (tmp_filename);
@@ -511,41 +513,62 @@ et_filename_prepare (gchar *filename_utf8,
     g_return_if_fail (filename_utf8 != NULL);
 
     // Convert automatically the directory separator ('/' on LINUX and '\' on WIN32) to '-'.
-    while ( (character=g_utf8_strchr(filename_utf8, -1, G_DIR_SEPARATOR))!=NULL )
+    while ((character = strchr (filename_utf8, G_DIR_SEPARATOR)) != NULL)
+    {
         *character = '-';
+    }
 
 #ifdef G_OS_WIN32
-    /* Convert character '\' on WIN32 to '-'. */
-    while ( (character=g_utf8_strchr(filename_utf8, -1, '\\'))!=NULL )
-        *character = '-';
     /* Convert character '/' on WIN32 to '-'. May be converted to '\' after. */
-    while ( (character=g_utf8_strchr(filename_utf8, -1, '/'))!=NULL )
+    while ((character = strchr (filename_utf8, '/')) != NULL)
+    {
         *character = '-';
+    }
 #endif /* G_OS_WIN32 */
 
     /* Convert other illegal characters on FAT32/16 filesystems and ISO9660 and
      * Joliet (CD-ROM filesystems). */
     if (replace_illegal)
     {
-        // Commented as we display unicode values as "\351" for "é"
-        //while ( (character=g_utf8_strchr(filename_utf8, -1, '\\'))!=NULL )
-        //    *character = ',';
-        while ( (character=g_utf8_strchr(filename_utf8, -1, ':'))!=NULL )
+        size_t last;
+
+        while ((character = strchr (filename_utf8, ':')) != NULL)
+        {
             *character = '-';
-        //while ( (character=g_utf8_strchr(filename_utf8, -1, ';'))!=NULL )
-        //    *character = '-';
-        while ( (character=g_utf8_strchr(filename_utf8, -1, '*'))!=NULL )
+        }
+        while ((character = strchr (filename_utf8, '*')) != NULL)
+        {
             *character = '+';
-        while ( (character=g_utf8_strchr(filename_utf8, -1, '?'))!=NULL )
+        }
+        while ((character = strchr (filename_utf8, '?')) != NULL)
+        {
             *character = '_';
-        while ( (character=g_utf8_strchr(filename_utf8, -1, '\"'))!=NULL )
+        }
+        while ((character = strchr (filename_utf8, '\"')) != NULL)
+        {
             *character = '\'';
-        while ( (character=g_utf8_strchr(filename_utf8, -1, '<'))!=NULL )
+        }
+        while ((character = strchr (filename_utf8, '<')) != NULL)
+        {
             *character = '(';
-        while ( (character=g_utf8_strchr(filename_utf8, -1, '>'))!=NULL )
+        }
+        while ((character = strchr (filename_utf8, '>')) != NULL)
+        {
             *character = ')';
-        while ( (character=g_utf8_strchr(filename_utf8, -1, '|'))!=NULL )
+        }
+        while ((character = strchr (filename_utf8, '|')) != NULL)
+        {
             *character = '-';
+        }
+
+        /* FAT has additional restrictions on the last character of a filename.
+         * https://msdn.microsoft.com/en-us/library/windows/desktop/aa365247%28v=vs.85%29.aspx#naming_conventions */
+        last = strlen (filename_utf8) - 1;
+
+        if (filename_utf8[last] == ' ' || filename_utf8[last] == '.')
+        {
+            filename_utf8[last] = '_';
+        }
     }
 }
 
