@@ -1,5 +1,5 @@
 /* EasyTAG - Tag editor for audio files
- * Copyright (C) 2014  David King <amigadave@amigadave.com>
+ * Copyright (C) 2014-2015  David King <amigadave@amigadave.com>
  * Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,6 @@
 
 #include "picture.h"
 
-#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
 #include "easytag.h"
@@ -237,6 +236,43 @@ Picture_Type_String (EtPictureType type)
     }
 }
 
+gboolean
+et_picture_detect_difference (const EtPicture *a,
+                              const EtPicture *b)
+{
+    if (!a && !b)
+    {
+        return FALSE;
+    }
+
+    if ((a && !b) || (!a && b))
+    {
+        return TRUE;
+    }
+
+    if (a->type != b->type)
+    {
+        return TRUE;
+    }
+
+    if ((a->width != b->width) || (a->height != b->height))
+    {
+        return TRUE;
+    }
+
+    if (et_normalized_strcmp0 (a->description, b->description) != 0)
+    {
+        return TRUE;
+    }
+
+    if (!g_bytes_equal (a->bytes, b->bytes))
+    {
+        return TRUE;
+    }
+
+    return FALSE;
+}
+
 gchar *
 et_picture_format_info (const EtPicture *pic,
                         ET_Tag_Type tag_type)
@@ -433,6 +469,16 @@ et_picture_load_file_data (GFile *file, GError **error)
 
         g_assert (error == NULL || *error == NULL);
 
+        if (g_memory_output_stream_get_data_size (G_MEMORY_OUTPUT_STREAM (ostream))
+            == 0)
+        {
+            g_object_unref (ostream);
+            /* FIXME: Mark up the string for translation. */
+            g_set_error (error, G_IO_ERROR, G_IO_ERROR_INVALID_DATA, "%s",
+                         "Input truncated or empty");
+            return NULL;
+        }
+
         bytes = g_memory_output_stream_steal_as_bytes (G_MEMORY_OUTPUT_STREAM (ostream));
 
         g_object_unref (ostream);
