@@ -439,7 +439,9 @@ write_button_clicked (EtPlaylistDialog *self)
     }
 
     // Path of the playlist file (may be truncated later if PLAYLIST_CREATE_IN_PARENT_DIR is TRUE)
-    playlist_path_utf8 = filename_to_display (et_application_window_get_current_path (ET_APPLICATION_WINDOW (MainWindow)));
+    temp = g_file_get_path (et_application_window_get_current_path (ET_APPLICATION_WINDOW (MainWindow)));
+    playlist_path_utf8 = g_filename_display_name (temp);
+    g_free (temp);
 
     /* Build the playlist filename. */
     if (g_settings_get_boolean (MainSettings, "playlist-use-mask"))
@@ -461,8 +463,8 @@ write_button_clicked (EtPlaylistDialog *self)
         g_free (temp);
 
         /* Replace Characters (with scanner). */
-        convert_mode = g_settings_get_flags (MainSettings,
-                                             "rename-convert-spaces");
+        convert_mode = g_settings_get_enum (MainSettings,
+                                            "rename-convert-spaces");
 
         switch (convert_mode)
         {
@@ -581,7 +583,7 @@ on_response (GtkDialog *dialog, gint response_id, gpointer user_data)
         case GTK_RESPONSE_OK:
             write_button_clicked (ET_PLAYLIST_DIALOG (dialog));
             break;
-        case GTK_RESPONSE_CLOSE:
+        case GTK_RESPONSE_CANCEL:
             gtk_widget_hide (GTK_WIDGET (dialog));
             break;
         case GTK_RESPONSE_DELETE_EVENT:
@@ -650,10 +652,14 @@ static void
 create_playlist_dialog (EtPlaylistDialog *self)
 {
     EtPlaylistDialogPrivate *priv;
+    GtkDialog *dialog;
 
     priv = et_playlist_dialog_get_instance_private (self);
+    dialog = GTK_DIALOG (self);
 
-    gtk_dialog_set_default_response (GTK_DIALOG (self), GTK_RESPONSE_OK);
+    gtk_dialog_add_buttons (dialog, _("_Cancel"), GTK_RESPONSE_CANCEL,
+                            _("_Save"), GTK_RESPONSE_OK, NULL);
+    gtk_dialog_set_default_response (dialog, GTK_RESPONSE_OK);
 
     /* Playlist name */
     g_settings_bind (MainSettings, "playlist-filename-mask",
