@@ -1,5 +1,5 @@
 /* EasyTAG - Tag editor for audio files
- * Copyright (C) 2014  David King <amigadave@amigadave.com>
+ * Copyright (C) 2014-2015  David King <amigadave@amigadave.com>
  * Copyright (C) 2001-2003  Jerome Couderc <easytag@gmail.com>
  * Copyright (C) 2002-2003  Artur Polaczyñski <artii@o2.pl>
  *
@@ -21,11 +21,11 @@
 #include "config.h"
 
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
 
-#include "easytag.h"
 #include "ape_tag.h"
 #include "et_core.h"
 #include "misc.h"
@@ -57,7 +57,7 @@ ape_tag_read_file_tag (GFile *file,
 
     filename = g_file_get_path (file);
 
-    if ((fp = fopen (filename, "rb")) == NULL)
+    if ((fp = g_fopen (filename, "rb")) == NULL)
     {
         g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (errno),
                      _("Error while opening file: %s"),
@@ -109,8 +109,7 @@ ape_tag_read_file_tag (GFile *file,
     {
         string = Try_To_Validate_Utf8_String (string);
 
-        /* strchr does not like NULL string. */
-        string1 = g_utf8_strchr (string, -1, '/');
+        string1 = strchr (string, '/');
 
         if (string1)
         {
@@ -142,7 +141,7 @@ ape_tag_read_file_tag (GFile *file,
     {
         string = Try_To_Validate_Utf8_String(string);
 
-        string1 = g_utf8_strchr(string, -1, '/');    // strchr don't like NULL string
+        string1 = strchr (string, '/');
 
         if (string1)
         {
