@@ -29,6 +29,7 @@
 #ifndef __BORLANDC__
 #    include <unistd.h>
 #endif
+#include <glib/gstdio.h>
 #include "apetaglib.h"
 #include "../genres.h"
 #include "../win32/win32dep.h"
@@ -515,12 +516,12 @@ libapetag_print_mem_cnt (apetag *mem_cnt)
     for (n = 0; (mem_cnt->countTag) > n; n++) {
         if ( (mTag[n]->flags & ~ITEM_TEXT) == 0 ||
             (mTag[n]->flags & ~ITEM_LINK) == 0 ) {
-        printf (">apetaglib>PRINT>>F=%li SN=%li SV=%li N[%s] V[%s]\n", 
+        printf (">apetaglib>PRINT>>F=%lu SN=%li SV=%li N[%s] V[%s]\n",
             mTag[n]->flags,
             (long) mTag[n]->sizeName, (long) mTag[n]->sizeValue, 
             mTag[n]->name, mTag[n]->value);
         } else {
-        printf (">apetaglib>PRINT>>F=%li SN=%li SV=%li N[%s] V=BINARY\n",
+        printf (">apetaglib>PRINT>>F=%lu SN=%li SV=%li N[%s] V=BINARY\n",
             mTag[n]->flags,
             (long) mTag[n]->sizeName, (long) mTag[n]->sizeValue, 
             mTag[n]->name);
@@ -816,7 +817,7 @@ apetag_read (apetag *mem_cnt, const char *filename, int flag)
         return ATL_NOINIT;
     }
     
-    fp = fopen (filename, "rb");
+    fp = g_fopen (filename, "rb");
     if (fp == NULL)
         return ATL_FOPEN;
 
@@ -902,7 +903,7 @@ apetag_save (const char *filename, apetag *mem_cnt, int flag)
         return ATL_NOINIT;
     }
 
-    fp = fopen (filename, "rb+");
+    fp = g_fopen (filename, "rb+");
     if (fp == NULL) {
         PRINT_ERR ( "ERROR->apetaglib->apetag_save::fopen (r+)\n");
         return ATL_FOPEN;
