@@ -264,7 +264,7 @@ et_add_file_tags_from_vorbis_comments (vorbis_comment *vc,
         {
             FileTag->disc_total = et_disc_number_to_string (atoi (string1));
         }
-        else if ((string1 = g_utf8_strchr (string, -1, '/')))
+        else if ((string1 = strchr (string, '/')))
         {
             FileTag->disc_total = et_disc_number_to_string (atoi (string1
                                                                   + 1));
@@ -297,7 +297,7 @@ et_add_file_tags_from_vorbis_comments (vorbis_comment *vc,
         {
             FileTag->track_total = et_track_number_to_string (atoi (string1));
         }
-        else if ((string1 = g_utf8_strchr (string, -1, '/')))
+        else if ((string1 = strchr (string, '/')))
         {
             FileTag->track_total = et_track_number_to_string (atoi (string1
                                                                     + 1));
@@ -658,8 +658,6 @@ ogg_tag_read_file_tag (GFile *file,
 {
     GFileInputStream *istream;
     EtOggState *state;
-    gchar *filename;
-    gchar *filename_utf8;
 
     g_return_val_if_fail (file != NULL && FileTag != NULL, FALSE);
     g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
@@ -672,10 +670,6 @@ ogg_tag_read_file_tag (GFile *file,
         return FALSE;
     }
 
-    filename = g_file_get_path (file);
-    filename_utf8 = filename_to_display (filename);
-    g_free (filename);
-
     {
     /* Check for an unsupported ID3v2 tag. */
     guchar tmp_id3[4];
@@ -728,7 +722,6 @@ ogg_tag_read_file_tag (GFile *file,
     {
         g_assert (error == NULL || *error != NULL);
         vcedit_clear(state);
-        g_free (filename_utf8);
         return FALSE;
     }
 
@@ -743,14 +736,12 @@ ogg_tag_read_file_tag (GFile *file,
 
     et_add_file_tags_from_vorbis_comments (vcedit_comments(state), FileTag);
     vcedit_clear(state);
-    g_free (filename_utf8);
 
     return TRUE;
 
 err:
     g_assert (error == NULL || *error != NULL);
     g_object_unref (istream);
-    g_free (filename_utf8);
     return FALSE;
 }
 
