@@ -33,6 +33,7 @@
 #include <windows.h>
 #include <io.h>
 #include <stdlib.h>
+#include <glib/gstdio.h>
 #include <stdio.h>
 #include <winuser.h>
 #include <sys/types.h>
@@ -40,33 +41,17 @@
 #include <fcntl.h>
 #include <sys/timeb.h>
 
-#include <gtk/gtk.h>
-#include <glib.h>
-#include <glib/gstdio.h>
-
-#include <gdk/gdkwin32.h>
-
 #include "resource.h"
-//#include "../log.h"
-
-#include <libintl.h>
 
 #include "win32dep.h"
 
-/*
- *  DEFINES & MACROS
- */
-#define _(x) gettext(x)
+const gchar * weasytag_install_dir (void);
 
 /*
  * LOCALS
  */
 static char *install_dir = NULL, *locale_dir = NULL;
 
-/* Prototypes. */
-void str_replace_char (gchar *str, gchar in_char, gchar out_char);
-
-
 /*
  *  PUBLIC CODE
  */
@@ -111,7 +96,7 @@ weasytag_locale_dir (void)
 
         if (inst_dir != NULL)
         {
-            locale_dir = g_build_filename (inst_dir, "lib", "locale", NULL);
+            locale_dir = g_build_filename (inst_dir, "share", "locale", NULL);
             initialized = TRUE;
         }
         else
@@ -124,73 +109,6 @@ weasytag_locale_dir (void)
 }
 
 /* Miscellaneous */
-#ifndef HAVE_MKSTEMP
-/* emulate the unix function */
-gint
-et_w32_mkstemp (gchar *template)
-{
-    int fd = -1;
-
-    char *str = mktemp(template);
-    if(str != NULL)
-    {
-        fd  = open(str, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR);
-    }
-
-    return fd;
-}
-#endif /* !HAVE_MKSTEMP */
-
-void
-str_replace_char (gchar *str, gchar in_char, gchar out_char)
-{
-    while(*str)
-    {
-        if(*str == in_char)
-            *str = out_char;
-        str++;
-    }
-}
-
-/* Remove trailing '/' if any */
-void ET_Win32_Path_Remove_Trailing_Slash (gchar *path)
-{
-    int path_len = strlen(path);
-  
-    if(path_len > 3 && path[path_len - 1] == '/')
-    {
-        path[path_len - 1] = '\0';
-    }
-}
-
-/* Remove trailing '\' if any, but not when 'C:\' */
-void ET_Win32_Path_Remove_Trailing_Backslash (gchar *path)
-{
-    int path_len = strlen(path);
-  
-    if(path_len > 3 && path[path_len - 1] == '\\')
-    {
-        path[path_len - 1] = '\0';
-    }
-}
-
-void ET_Win32_Path_Replace_Backslashes (gchar *path)
-{
-    str_replace_char(path, '\\', '/');
-}
-
-void ET_Win32_Path_Replace_Slashes (gchar *path)
-{
-    str_replace_char(path, '/', '\\');
-}
-
-/* find a default player executable */
-gchar *
-ET_Win32_Get_Audio_File_Player (void)
-{
-    return g_strdup("");
-}
-
 #ifndef HAVE_TRUNCATE
 gint
 et_w32_truncate (const gchar *path, off_t length)
