@@ -34,11 +34,7 @@
 
 G_BEGIN_DECLS
 
-#define lstat stat
-#define mkdir(a,b) mkdir(a)
-#define chown(a,b,c) 0
-#define chmod(a,b)
-
+#include "config.h"
 
 /*
  *  PROTOS
@@ -50,22 +46,8 @@ G_BEGIN_DECLS
 /* Windows helper functions */
 
 /* Determine EasyTAG paths */
-const gchar * weasytag_install_dir (void);
 const gchar * weasytag_locale_dir (void);
 
-/* Misc */
-extern char *ET_Win32_Get_Audio_File_Player (void);
-
-extern void  ET_Win32_Path_Remove_Trailing_Slash     (gchar *path);
-extern void  ET_Win32_Path_Remove_Trailing_Backslash (gchar *path);
-extern void  ET_Win32_Path_Replace_Backslashes       (gchar *path);
-extern void  ET_Win32_Path_Replace_Slashes           (gchar *path);
-
-#ifndef HAVE_MKSTEMP
-#define et_w32_mkstemp mkstemp
-extern gint et_w32_mkstemp (char *template);
-#endif /* HAVE_MKSTEMP */
-
 #ifndef HAVE_TRUNCATE
 #define et_w32_truncate truncate
 extern gint et_w32_truncate (const gchar *path, off_t length);
@@ -78,9 +60,7 @@ extern gint et_w32_truncate (const gchar *path, off_t length);
 /*
  *  EasyTAG specific
  */
-#undef DATADIR
 #undef LOCALEDIR
-#define DATADIR weasytag_install_dir()
 #define LOCALEDIR weasytag_locale_dir()
 
 G_END_DECLS
